Rum & Tonka Bean Dark Chocolate Truffles - sweetest kitchen
Description: Dark chocolate truffles with a unique rum and tonka bean twist.
Date: 2014-11-06T03:37:00+00:00

- Skip to primary navigation
- Skip to content
- Skip to primary sidebar
- Skip to footer

# Rum & Tonka Bean Dark Chocolate Truffles

06/11/2014 by jamieanne 7 Comments

Facebook
27
Twitter
0
Pinterest
3.5k
email

When Nespresso sent me a parcel full of gourmet ingredients last month to celebrate the launch of Cubania, I didn’t think I’d have any trouble dreaming up recipes to use them in. I presented you with the rum and espresso cloud cake, but after that, life got in the way and the blog went on a tiny hiatus. Possible recipes kept floating around in the back of my mind for the past month, only I just couldn’t find the time to make them a reality. Well, in all honesty, I did prepare one other recipe – which was tonka bean ice cream with a coffee-caramel swirl – but it did not work out. The ice cream was okay, but the caramel wasn’t thick enough (although it was really delicious) so it would have been impossible to swirl into the ice cream. I never got around to making another batch of the caramel.

The other day, however, I had a new recipe idea. It involved lots of chocolate.

Not just any chocolate, but the good chocolate that was stashed away for special occasions – the Callebaut chocolate. It also involved a bit of rum and tonka bean-infused cream.

These rum and tonka bean truffles were not going to include coffee, like my other Nespresso-inspired recipes, but instead, would be excellent alongside a tiny cup of Cubania.

How sinful do those truffles look! After a bit of brainstorming and looking at a few truffle recipes for inspiration, I decided to infuse some thickened cream with grated tonka bean. Like vanilla beans, to really get the flavor from the tonka beans, it’s best to heat the cream and then let it infuse for about 15 minutes. The cream can then be strained to remove the bigger pieces of the tonka bean.

After gently re-heating the cream, tons of dark chocolate is added to the pan and melted down. Once the mixture is smooth, remove from the heat, and stir in the rum. This turns the chocolate ganache into an incredibly gorgeous, silky pot of the dreamiest chocolate.

Normally, truffles are rolled into balls, but I decided to do it a little differently. I’ve always liked the idea of square truffles. So I poured the chocolate into a rectangular dish and let it completely set in the refrigerator. When I removed the chocolate from the dish, I trimmed off the messy edges and cut the block of chocolate (with a warm, dry knife) into about 18 1-inch (3cm) squares. The finishing touch is a dusting of cocoa powder.

These gorgeous little chocolate squares have the silkiest texture. The flavor of the rum and tonka bean are subtle. Unfortunately, the flavors of the rum and tonka bean diminish somewhat overnight in the refrigerator. When served immediately at room temperature, however, wow.

They were so good, in fact, that I packed some into ziploc bags and took them with me to school pickup to give to some of my friends! As far as I know, everyone loved them! Although, admittedly, it did feel a little awkward to inform them that they contained tonka beans and tonka beans are toxic in large doses, but I did ensure them I had been sampling tonka bean-infused recipes for the past month and I have survived! 🙂

But if I had died while consuming a bucketload of these truffles, it would almost have been worth it! Haha!

If you’re reading this and thinking to yourself, where am I going to find tonka beans to make these truffles?, the tonka beans I received came from The Essential Ingredient. However, if you’re in the US, you’re out of luck as I believe they have been banned due to their toxicity (but I hear you can still buy them on eBay, shhh). If you still can’t get your hands on the tonka beans, don’t fret. You can replace them with vanilla beans, or just use the cream as-is.

Back to the whole reason I created these truffles – for the ultimate Central American experience, serve these truffles up with that cup of Cubania, Nespresso’s most intense coffee yet. It’s only available for a limited time, so if you haven’t yet tried it, give it a go before it runs out!

**I was not compensated for this post, however, I did receive free samples to review and create some yummy recipes with. All opinions are my own and not influenced in any way.

5.0 from 2 reviews
Rum & Tonka Bean Dark Chocolate Truffles
Print
Prep time
4 hours 30 mins
Cook time
10 mins
Total time
4 hours 40 mins
Dark chocolate truffles with a unique rum and tonka bean twist.
Author: Jamieanne
Recipe type: Dessert
Serves: 15-18 3cm squares
Ingredients

- 125ml (1/2 cup) thickened cream
- ½ tonka bean, or 1 whole small bean
- 400g dark chocolate, chopped
- 2 tablespoons rum
- Cocoa powder, for dusting

Instructions

1. Add cream to a small saucepan and finely grate the tonka bean over it. Give it a few stirs and gently heat until just under a simmer - do not let it boil. Remove from the heat and let infuse for 15 minutes. Strain the cream and return to the saucepan.
2. Gently reheat the cream to just under a simmer - do not let it boil - then reduce the heat to low and add the chopped chocolate to the cream. Stir constantly until the chocolate is just about melted and a few smallish lumps remain. Remove from the heat and stir the chocolate until it is smooth and the lumps have melted.
3. Stir in the rum until it is completely combined and the chocolate is silky and smooth. Line an approximate 17 x 11.5cm dish with parchment paper (make sure some of the paper overhangs for easy removal later) and pour the chocolate into it. Place into the refrigerator to set for at least 4 hours.
4. Remove the dish from the refrigerator and pull out the chocolate using the overhanging parchment paper. Peel away the paper from the chocolate.
5. Warm a sharp, straight knife under running water from the tap and dry completely. Trim off the messy edges from the chocolate (only if you want all neat edges, otherwise, don't worry about trimming the edges). Cut the remaining rectangle of chocolate into 3cm squares (or whatever size you'd like).
6. Once you've made all the cuts, dust some cocoa powder over the squares and serve within an hour or two for maximum flavor.
7. Store leftovers in the refrigerator, but know the subtle flavor of the rum and tonka bean will diminish overnight.

3.2.2807

### Related Posts

- Espresso & Rum Chocolate Cloud Cake With Tonka Bean Whipped Cream
- Rum & Pecan French Toast With Salted Burnt Honey Sauce
- A Morning of Coffee and Good Food
- Espresso Brigadeiros

Facebook
27
Twitter
0
Pinterest
3.5k
email

### Did you like this recipe?

If you enjoyed this recipe, please leave a comment, hit up one of those stars to rate it, and be sure to tag any photos with #sweetestkitchen on Instagram if you made this recipe! I'd love to see what you've created!

« A Morning of Coffee and Good Food
Homemade Biscoff Spread »

## Reader Interactions

### Comments

1. Fiona Johnson

   06/11/2014 at 5:03 AM

   I was one of the lucky friends at school pick up and I can say the truffles are delicious!

   Reply

   - jamieanne

     06/11/2014 at 10:30 AM

     Aw!!! Thank you, Fiona! 🙂

     Reply

2. Oana

   06/11/2014 at 9:03 PM

   I have yet to try tonka beans, but look at these truffles! So much chocolate! Amazing pictures, they speak for themselves 🙂

   Reply

3. Kate @ foodiesagenda

   04/02/2015 at 7:20 AM

   These look divine! Can I skip dinner please & just eat a plate of these?

   Reply

4. Linda

   04/10/2015 at 11:22 PM

   what are tonka beans and where do I get them? These look fabulous!

   Reply

   - jamieanne

     11/05/2016 at 10:09 AM

     Hi Linda, I’m not sure where you live, but here in Sydney, you can buy them from The Essential Ingredient in Rozelle. They also have an online shop (search for The Essential Ingredient on google). I don’t think tonka beans are a common item in any shop around the world, so you may need to search online to have them delivered to you.

     Reply

5. Makos (@thehungrybites)

   12/12/2016 at 12:34 AM

   This one goes straight to my favorites!!!
   Thanks for sharing Jamieanne 🙂

   Reply

### Leave a Reply Cancel reply

Your email address will not be published. Required fields are marked *

Comment

Name *

Email *

Website

Save my name, email, and website in this browser for the next time I comment.

Rate this recipe: